package sun.swing.text;

import java.awt.print.PrinterException;
import java.awt.print.PageFormat;
import java.awt.Graphics;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;

class CompoundPrintable implements CountingPrintable
{
    private final Queue<CountingPrintable> printables;
    private int offset;
    
    public CompoundPrintable(List<CountingPrintable> c) {
        this.offset = 0;
        this.printables = new LinkedList(c);
    }
    
    @Override
    public int print(Graphics graphics, PageFormat pageFormat, int n) throws PrinterException {
        int print = 1;
        while (this.printables.peek() != null) {
            print = ((CountingPrintable)this.printables.peek()).print(graphics, pageFormat, n - this.offset);
            if (print == 0) {
                break;
            }
            this.offset += ((CountingPrintable)this.printables.poll()).getNumberOfPages();
        }
        return print;
    }
    
    @Override
    public int getNumberOfPages() {
        return this.offset;
    }
}
